<?php // phpcs:ignore WordPress.Files.FileName.NotHyphenatedLowercase
/**
 * Customizer top info options service.
 *
 * @package PressBook_Media
 */

/**
 * Top info options service class.
 */
class PressBook_Media_TopInfo extends PressBook\Options {
	const BUTTONS            = 3;
	const ALIGN_SCREEN_SIZES = array( 'xlg', 'lg', 'md' );

	/**
	 * Register service features.
	 */
	public function register() {
		add_action( 'customize_register', array( $this, 'customize_register' ) );
		add_action( 'customize_preview_init', array( $this, 'customize_preview_scripts' ), 11 );
	}

	/**
	 * Add top info options for theme customizer.
	 *
	 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
	 */
	public function customize_register( $wp_customize ) {
		$this->sec_top_info( $wp_customize );

		$this->set_top_info_contact_enable( $wp_customize );

		$this->set_top_info_contact_phone( $wp_customize );
		$this->set_top_info_contact_email( $wp_customize );
		$this->set_top_info_contact_address( $wp_customize );

		foreach ( array_keys( $this->top_info_contact_order_label() ) as $field ) {
			$this->set_top_info_contact_field_order( $wp_customize, $field );
		}

		$this->set_top_info_bg_color( $wp_customize );
		$this->set_top_info_color( $wp_customize );
		$this->set_top_info_font_wgt( $wp_customize );

		$this->set_top_info_buttons_enable( $wp_customize );

		for ( $i = 1; $i <= static::BUTTONS; $i++ ) {
			$this->set_top_info_button( $wp_customize, $i );
		}

		$this->set_top_info_button_bg_color( $wp_customize );
		$this->set_top_info_button_border_color( $wp_customize );
		$this->set_top_info_button_color( $wp_customize );

		foreach ( static::ALIGN_SCREEN_SIZES as $size ) {
			$this->set_top_info_align( $wp_customize, $size );
		}
	}

	/**
	 * Binds JS handlers to make theme customizer preview reload changes asynchronously.
	 */
	public function customize_preview_scripts() {
		wp_localize_script(
			'pressbook-customizer',
			'pressbook',
			array(
				'styles'    => PressBook_Media_CSSRules::output_array(),
				'handle_id' => apply_filters( 'pressbook_media_inline_style_handle_id', 'pressbook-media-style-inline-css' ),
			)
		);
	}

	/**
	 * Section: Top Info Options.
	 *
	 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
	 */
	public function sec_top_info( $wp_customize ) {
		$wp_customize->add_section(
			'sec_top_info',
			array(
				'title'       => esc_html__( 'Top Info Section', 'pressbook-media' ),
				'description' => esc_html__( 'You can customize the top info options in here.', 'pressbook-media' ),
				'priority'    => 151,
			)
		);
	}

	/**
	 * Add setting: Enable Top Contact Info.
	 *
	 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
	 */
	public function set_top_info_contact_enable( $wp_customize ) {
		$wp_customize->add_setting(
			'set_top_info_contact_enable',
			array(
				'default'           => static::get_top_info_contact_enable( true ),
				'transport'         => 'postMessage',
				'sanitize_callback' => array( PressBook\Options\Sanitizer::class, 'sanitize_checkbox' ),
			)
		);

		$wp_customize->add_control(
			'set_top_info_contact_enable',
			array(
				'section'     => 'sec_top_info',
				'type'        => 'checkbox',
				'label'       => esc_html__( 'Enable Top Contact Info', 'pressbook-media' ),
				'description' => esc_html__( 'You can show the contact info such as email, phone, and address at the top section above the primary menu.', 'pressbook-media' ),
			)
		);

		$wp_customize->selective_refresh->add_partial(
			'set_top_info_contact_enable',
			array(
				'selector'            => '.top-info',
				'container_inclusive' => true,
				'render_callback'     => array( $this, 'render_top_info' ),
			)
		);
	}

	/**
	 * Get setting: Enable Top Contact Info.
	 *
	 * @param bool $get_default Get default.
	 * @return bool
	 */
	public static function get_top_info_contact_enable( $get_default = false ) {
		$default = apply_filters( 'pressbook_default_top_info_contact_enable', false );
		if ( $get_default ) {
			return $default;
		}

		return get_theme_mod( 'set_top_info_contact_enable', $default );
	}

	/**
	 * Add setting: Top Contact Info: Contact Phone.
	 *
	 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
	 */
	public function set_top_info_contact_phone( $wp_customize ) {
		$wp_customize->add_setting(
			'set_top_info_contact[field][phone]',
			array(
				'default'           => self::get_top_info_contact_default( 'field' )['phone'],
				'transport'         => 'postMessage',
				'sanitize_callback' => array( PressBook_Media_Helpers::class, 'sanitize_phone' ),
			)
		);

		$wp_customize->add_control(
			'set_top_info_contact[field][phone]',
			array(
				'section'     => 'sec_top_info',
				'type'        => 'text',
				'label'       => esc_html__( 'Contact Phone', 'pressbook-media' ),
				'description' => esc_html__( 'Example: +1-123-456-7890', 'pressbook-media' ),
			)
		);

		$wp_customize->selective_refresh->add_partial(
			'set_top_info_contact[field][phone]',
			array(
				'selector'            => '.top-info',
				'container_inclusive' => true,
				'render_callback'     => array( $this, 'render_top_info' ),
			)
		);
	}

	/**
	 * Add setting: Top Contact Info: Contact Email.
	 *
	 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
	 */
	public function set_top_info_contact_email( $wp_customize ) {
		$wp_customize->add_setting(
			'set_top_info_contact[field][email]',
			array(
				'default'           => self::get_top_info_contact_default( 'field' )['email'],
				'transport'         => 'postMessage',
				'sanitize_callback' => 'sanitize_text_field',
			)
		);

		$wp_customize->add_control(
			'set_top_info_contact[field][email]',
			array(
				'section'     => 'sec_top_info',
				'type'        => 'text',
				'label'       => esc_html__( 'Contact Email', 'pressbook-media' ),
				'description' => esc_html__( 'Example: info@example.com', 'pressbook-media' ),
			)
		);

		$wp_customize->selective_refresh->add_partial(
			'set_top_info_contact[field][email]',
			array(
				'selector'            => '.top-info',
				'container_inclusive' => true,
				'render_callback'     => array( $this, 'render_top_info' ),
			)
		);
	}

	/**
	 * Add setting: Top Contact Info: Contact Address.
	 *
	 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
	 */
	public function set_top_info_contact_address( $wp_customize ) {
		$wp_customize->add_setting(
			'set_top_info_contact[field][address]',
			array(
				'default'           => self::get_top_info_contact_default( 'field' )['address'],
				'transport'         => 'postMessage',
				'sanitize_callback' => 'sanitize_text_field',
			)
		);

		$wp_customize->add_control(
			'set_top_info_contact[field][address]',
			array(
				'section'     => 'sec_top_info',
				'type'        => 'text',
				'label'       => esc_html__( 'Contact Address', 'pressbook-media' ),
				'description' => esc_html__( 'Example: 101, Sample Street, City, State', 'pressbook-media' ),
			)
		);

		$wp_customize->selective_refresh->add_partial(
			'set_top_info_contact[field][address]',
			array(
				'selector'            => '.top-info',
				'container_inclusive' => true,
				'render_callback'     => array( $this, 'render_top_info' ),
			)
		);
	}

	/**
	 * Add setting: Top Contact Info: Contact Field: Order.
	 *
	 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
	 * @param string               $field Contact field.
	 */
	public function set_top_info_contact_field_order( $wp_customize, $field ) {
		$set_id = ( 'set_top_info_contact[order][' . $field . ']' );

		$wp_customize->add_setting(
			$set_id,
			array(
				'default'           => self::get_top_info_contact_default( 'order' )[ $field ],
				'transport'         => 'postMessage',
				'sanitize_callback' => 'absint',
			)
		);

		$wp_customize->add_control(
			$set_id,
			array(
				'section'     => 'sec_top_info',
				'type'        => 'number',
				'label'       => $this->top_info_contact_order_label()[ $field ]['label'],
				'description' => $this->top_info_contact_order_label()[ $field ]['desc'],
			)
		);

		$wp_customize->selective_refresh->add_partial(
			$set_id,
			array(
				'selector'            => '.top-info',
				'container_inclusive' => true,
				'render_callback'     => array( $this, 'render_top_info' ),
			)
		);
	}

	/**
	 * Get setting label: Top Contact Info: Order.
	 *
	 * @return array
	 */
	public function top_info_contact_order_label() {
		return array(
			'phone'   => array(
				'label' => esc_html__( 'Contact Phone: Order', 'pressbook-media' ),
				'desc'  => esc_html__( 'Adjust the order of phone field. Default: 1', 'pressbook-media' ),
			),
			'email'   => array(
				'label' => esc_html__( 'Contact Email: Order', 'pressbook-media' ),
				'desc'  => esc_html__( 'Adjust the order of email field. Default: 2', 'pressbook-media' ),
			),
			'address' => array(
				'label' => esc_html__( 'Contact Address: Order', 'pressbook-media' ),
				'desc'  => esc_html__( 'Adjust the order of address field. Default: 3', 'pressbook-media' ),
			),
		);
	}

	/**
	 * Get default setting: Top Contact Info.
	 *
	 * @param string $key Setting key.
	 * @return array
	 */
	public static function get_top_info_contact_default( $key = '' ) {
		$default = apply_filters(
			'pressbook_default_top_info_contact',
			array(
				'field' => array(
					'phone'   => '',
					'email'   => '',
					'address' => '',
				),
				'order' => array(
					'phone'   => 1,
					'email'   => 2,
					'address' => 3,
				),
			)
		);

		if ( array_key_exists( $key, $default ) ) {
			return $default[ $key ];
		}

		return $default;
	}

	/**
	 * Get setting: Top Contact Info.
	 *
	 * @return array
	 */
	public static function get_top_info_contact() {
		$contact = wp_parse_args(
			get_theme_mod( 'set_top_info_contact', array() ),
			static::get_top_info_contact_default()
		);

		$field = wp_parse_args( $contact['field'], static::get_top_info_contact_default()['field'] );
		$order = wp_parse_args( $contact['order'], static::get_top_info_contact_default()['order'] );

		asort( $order );

		return array(
			'field' => $field,
			'order' => $order,
		);
	}

	/**
	 * Add setting: Top Info Background Color.
	 *
	 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
	 */
	public function set_top_info_bg_color( $wp_customize ) {
		$wp_customize->add_setting(
			'set_styles[top_info_bg_color]',
			array(
				'default'           => PressBook\CSSRules::default_styles( 'top_info_bg_color' ),
				'transport'         => 'postMessage',
				'sanitize_callback' => array( PressBook\Options\Sanitizer::class, 'sanitize_alpha_color' ),
			)
		);

		$wp_customize->add_control(
			new PressBook\Options\AlphaColorControl(
				$wp_customize,
				'set_styles[top_info_bg_color]',
				array(
					'section'      => 'sec_top_info',
					'label'        => esc_html__( 'Top Info Background Color', 'pressbook-media' ),
					'settings'     => 'set_styles[top_info_bg_color]',
					'palette'      => true,
					'show_opacity' => true,
				)
			)
		);
	}

	/**
	 * Add setting: Top Info Text Color.
	 *
	 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
	 */
	public function set_top_info_color( $wp_customize ) {
		$wp_customize->add_setting(
			'set_styles[top_info_color]',
			array(
				'default'           => PressBook\CSSRules::default_styles( 'top_info_color' ),
				'transport'         => 'postMessage',
				'sanitize_callback' => 'sanitize_hex_color',
			)
		);

		$wp_customize->add_control(
			new \WP_Customize_Color_Control(
				$wp_customize,
				'set_styles[top_info_color]',
				array(
					'section' => 'sec_top_info',
					'label'   => esc_html__( 'Top Info Text Color', 'pressbook-media' ),
				)
			)
		);
	}

	/**
	 * Add setting: Top Info Font Weight.
	 *
	 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
	 */
	public function set_top_info_font_wgt( $wp_customize ) {
		$wp_customize->add_setting(
			'set_styles[top_info_font_wgt]',
			array(
				'default'           => PressBook\CSSRules::default_styles( 'top_info_font_wgt' ),
				'transport'         => 'postMessage',
				'sanitize_callback' => array( PressBook\Options\Sanitizer::class, 'sanitize_select' ),
			)
		);

		$wp_customize->add_control(
			'set_styles[top_info_font_wgt]',
			array(
				'section'     => 'sec_top_info',
				'type'        => 'select',
				'choices'     => $this->font_weights(),
				'label'       => esc_html__( 'Top Info Font Weight', 'pressbook-media' ),
				'description' => esc_html__( 'Default: 600', 'pressbook-media' ),
			)
		);
	}

	/**
	 * Add setting: Enable Top Info Buttons.
	 *
	 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
	 */
	public function set_top_info_buttons_enable( $wp_customize ) {
		$wp_customize->add_setting(
			'set_top_info_buttons_enable',
			array(
				'default'           => static::get_top_info_buttons_enable( true ),
				'transport'         => 'postMessage',
				'sanitize_callback' => array( PressBook\Options\Sanitizer::class, 'sanitize_checkbox' ),
			)
		);

		$wp_customize->add_control(
			'set_top_info_buttons_enable',
			array(
				'section'     => 'sec_top_info',
				'type'        => 'checkbox',
				'label'       => esc_html__( 'Enable Top Info Buttons', 'pressbook-media' ),
				'description' => esc_html__( 'You can enable or disable the top info buttons.', 'pressbook-media' ),
			)
		);

		$wp_customize->selective_refresh->add_partial(
			'set_top_info_buttons_enable',
			array(
				'selector'            => '.top-info',
				'container_inclusive' => true,
				'render_callback'     => array( $this, 'render_top_info' ),
			)
		);
	}

	/**
	 * Get setting: Enable Top Info Buttons.
	 *
	 * @param bool $get_default Get default.
	 * @return bool
	 */
	public static function get_top_info_buttons_enable( $get_default = false ) {
		$default = apply_filters( 'pressbook_default_top_info_buttons_enable', false );
		if ( $get_default ) {
			return $default;
		}

		return get_theme_mod( 'set_top_info_buttons_enable', $default );
	}

	/**
	 * Add setting: Top Info Button.
	 *
	 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
	 * @param int                  $id Button number.
	 */
	public function set_top_info_button( $wp_customize, $id ) {
		$set_id = ( 'set_top_info_button[' . $id . ']' );

		$set_id_text = ( $set_id . '[text]' );

		$wp_customize->add_setting(
			$set_id_text,
			array(
				'default'           => self::get_top_info_button_default( 'text' ),
				'transport'         => 'postMessage',
				'sanitize_callback' => 'sanitize_text_field',
			)
		);

		$wp_customize->add_control(
			$set_id_text,
			array(
				'section'     => 'sec_top_info',
				'type'        => 'text',
				/* translators: %s: Top info button number */
				'label'       => sprintf( esc_html__( 'Button %d: Text', 'pressbook-media' ), $id ),
				'description' => esc_html__( 'Remove the text to disable this button.', 'pressbook-media' ),
			)
		);

		$wp_customize->selective_refresh->add_partial(
			$set_id_text,
			array(
				'selector'            => '.top-info',
				'container_inclusive' => true,
				'render_callback'     => array( $this, 'render_top_info' ),
			)
		);

		$set_id_link = ( $set_id . '[link]' );

		$wp_customize->add_setting(
			$set_id_link,
			array(
				'default'           => self::get_top_info_button_default( 'link' ),
				'transport'         => 'postMessage',
				'sanitize_callback' => 'esc_url_raw',
			)
		);

		$wp_customize->add_control(
			$set_id_link,
			array(
				'section' => 'sec_top_info',
				'type'    => 'text',
				/* translators: %s: Top info button number */
				'label'   => sprintf( esc_html__( 'Button %d: Link (URL)', 'pressbook-media' ), $id ),
			)
		);

		$wp_customize->selective_refresh->add_partial(
			$set_id_link,
			array(
				'selector'            => '.top-info',
				'container_inclusive' => true,
				'render_callback'     => array( $this, 'render_top_info' ),
			)
		);

		$set_id_new_tab = ( $set_id . '[new_tab]' );

		$wp_customize->add_setting(
			$set_id_new_tab,
			array(
				'default'           => self::get_top_info_button_default( 'new_tab' ),
				'transport'         => 'postMessage',
				'sanitize_callback' => array( PressBook\Options\Sanitizer::class, 'sanitize_checkbox' ),
			)
		);

		$wp_customize->add_control(
			$set_id_new_tab,
			array(
				'section' => 'sec_top_info',
				'type'    => 'checkbox',
				/* translators: %s: Top info button number */
				'label'   => sprintf( esc_html__( 'Button %d: Open Link in New Tab', 'pressbook-media' ), $id ),
			)
		);

		$wp_customize->selective_refresh->add_partial(
			$set_id_new_tab,
			array(
				'selector'            => '.top-info',
				'container_inclusive' => true,
				'render_callback'     => array( $this, 'render_top_info' ),
			)
		);
	}

	/**
	 * Get default setting: Top Info Button.
	 *
	 * @param string $key Setting key.
	 * @return array
	 */
	public static function get_top_info_button_default( $key = '' ) {
		$default = apply_filters(
			'pressbook_default_top_info_button',
			array(
				'text'    => '',
				'link'    => '#',
				'new_tab' => false,
			)
		);

		if ( array_key_exists( $key, $default ) ) {
			return $default[ $key ];
		}

		return $default;
	}

	/**
	 * Get setting: Top Info Buttons.
	 *
	 * @return array
	 */
	public static function get_top_info_buttons() {
		$buttons = get_theme_mod( 'set_top_info_button', array() );

		for ( $i = 1; $i <= static::BUTTONS; $i++ ) {
			if ( array_key_exists( $i, $buttons ) ) {
				$buttons[ $i ] = wp_parse_args( $buttons[ $i ], self::get_top_info_button_default() );
			} else {
				$buttons[ $i ] = self::get_top_info_button_default();
			}
		}

		return $buttons;
	}

	/**
	 * Add setting: Top Info: Button Background Color.
	 *
	 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
	 */
	public function set_top_info_button_bg_color( $wp_customize ) {
		$wp_customize->add_setting(
			'set_styles[top_info_button_bg_color]',
			array(
				'default'           => PressBook\CSSRules::default_styles( 'top_info_button_bg_color' ),
				'transport'         => 'postMessage',
				'sanitize_callback' => array( PressBook\Options\Sanitizer::class, 'sanitize_alpha_color' ),
			)
		);

		$wp_customize->add_control(
			new PressBook\Options\AlphaColorControl(
				$wp_customize,
				'set_styles[top_info_button_bg_color]',
				array(
					'section'      => 'sec_top_info',
					'label'        => esc_html__( 'Top Info: Button Background Color', 'pressbook-media' ),
					'settings'     => 'set_styles[top_info_button_bg_color]',
					'palette'      => true,
					'show_opacity' => true,
				)
			)
		);
	}

	/**
	 * Add setting: Top Info: Button Border Color.
	 *
	 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
	 */
	public function set_top_info_button_border_color( $wp_customize ) {
		$wp_customize->add_setting(
			'set_styles[top_info_button_border_color]',
			array(
				'default'           => PressBook\CSSRules::default_styles( 'top_info_button_border_color' ),
				'transport'         => 'postMessage',
				'sanitize_callback' => array( PressBook\Options\Sanitizer::class, 'sanitize_alpha_color' ),
			)
		);

		$wp_customize->add_control(
			new PressBook\Options\AlphaColorControl(
				$wp_customize,
				'set_styles[top_info_button_border_color]',
				array(
					'section'      => 'sec_top_info',
					'label'        => esc_html__( 'Top Info: Button Border Color', 'pressbook-media' ),
					'settings'     => 'set_styles[top_info_button_border_color]',
					'palette'      => true,
					'show_opacity' => true,
				)
			)
		);
	}

	/**
	 * Add setting: Top Info: Button Text Color.
	 *
	 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
	 */
	public function set_top_info_button_color( $wp_customize ) {
		$wp_customize->add_setting(
			'set_styles[top_info_button_color]',
			array(
				'default'           => PressBook\CSSRules::default_styles( 'top_info_button_color' ),
				'transport'         => 'postMessage',
				'sanitize_callback' => 'sanitize_hex_color',
			)
		);

		$wp_customize->add_control(
			new \WP_Customize_Color_Control(
				$wp_customize,
				'set_styles[top_info_button_color]',
				array(
					'section' => 'sec_top_info',
					'label'   => esc_html__( 'Top Info: Button Text Color', 'pressbook-media' ),
				)
			)
		);
	}

	/**
	 * Add setting: Top Info Section Alignment.
	 *
	 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
	 * @param string               $size Screen size.
	 */
	public function set_top_info_align( $wp_customize, $size ) {
		$set_id = ( 'set_top_info_align[' . $size . ']' );

		$wp_customize->add_setting(
			$set_id,
			array(
				'default'           => self::get_top_info_align_default( $size ),
				'transport'         => 'postMessage',
				'sanitize_callback' => array( PressBook\Options\Sanitizer::class, 'sanitize_select' ),
			)
		);

		$wp_customize->add_control(
			$set_id,
			array(
				'section'     => 'sec_top_info',
				'type'        => 'select',
				'choices'     => $this->top_info_alignments(),
				'label'       => $this->get_top_info_align_label()['label'][ $size ],
				'description' => $this->get_top_info_align_label()['desc'][ $size ],
			)
		);

		$wp_customize->selective_refresh->add_partial(
			$set_id,
			array(
				'selector'            => '.top-info',
				'container_inclusive' => true,
				'render_callback'     => array( $this, 'render_top_info' ),
			)
		);
	}

	/**
	 * Get setting: Top Info Section Alignment.
	 *
	 * @return array
	 */
	public static function get_top_info_align() {
		return wp_parse_args(
			get_theme_mod( 'set_top_info_align', array() ),
			self::get_top_info_align_default()
		);
	}

	/**
	 * Get default setting: Top Info Section Alignment.
	 *
	 * @param string $key Setting key.
	 * @return mixed|array
	 */
	public static function get_top_info_align_default( $key = '' ) {
		$default = apply_filters(
			'pressbook_default_top_info_align',
			array(
				'md'  => 'center',
				'lg'  => 'between',
				'xlg' => 'between',
			)
		);

		if ( array_key_exists( $key, $default ) ) {
			return $default[ $key ];
		}

		return $default;
	}

	/**
	 * Get setting label: Top Info Section Alignment.
	 *
	 * @return array
	 */
	public function get_top_info_align_label() {
		return array(
			'label' => array(
				'md'  => esc_html__( 'Alignment (Medium Screen-Devices)', 'pressbook-media' ),
				'lg'  => esc_html__( 'Alignment (Large Screen-Devices)', 'pressbook-media' ),
				'xlg' => esc_html__( 'Alignment (Extra Large Screen-Devices)', 'pressbook-media' ),
			),
			'desc'  => array(
				'md'  => esc_html_x( 'Default: Center', 'Default: Top Info Section Alignment (Medium Screen-Devices)', 'pressbook-media' ),
				'lg'  => esc_html_x( 'Default: Space Between', 'Default: Top Info Section Alignment (Large Screen-Devices)', 'pressbook-media' ),
				'xlg' => esc_html_x( 'Default: Space Between', 'Default: Top Info Section Alignment (Extra Large Screen-Devices)', 'pressbook-media' ),
			),
		);
	}

	/**
	 * Get available alignments.
	 *
	 * @return array.
	 */
	public function top_info_alignments() {
		return array(
			'between' => esc_html_x( 'Space Between', 'Top Info Section Alignment', 'pressbook-media' ),
			'center'  => esc_html_x( 'Center', 'Top Info Section Alignment', 'pressbook-media' ),
			'around'  => esc_html_x( 'Space Around', 'Top Info Section Alignment', 'pressbook-media' ),
		);
	}

	/**
	 * Font Weights.
	 *
	 * @return array
	 */
	public function font_weights() {
		return array(
			'100' => esc_html_x( '100', 'Font Weight', 'pressbook-media' ),
			'200' => esc_html_x( '200', 'Font Weight', 'pressbook-media' ),
			'300' => esc_html_x( '300', 'Font Weight', 'pressbook-media' ),
			'400' => esc_html_x( '400', 'Font Weight', 'pressbook-media' ),
			'500' => esc_html_x( '500', 'Font Weight', 'pressbook-media' ),
			'600' => esc_html_x( '600', 'Font Weight', 'pressbook-media' ),
			'700' => esc_html_x( '700', 'Font Weight', 'pressbook-media' ),
		);
	}

	/**
	 * Output the top info icon.
	 *
	 * @param string $icon Icon key.
	 */
	public static function output_icon( $icon ) {
		$icons = apply_filters(
			'pressbook_media_top_info_icons',
			array(
				'phone'   => '<svg class="svg-icon" width="24" height="24" aria-hidden="true" role="img" focusable="false" viewBox="0 0 1792 1792" xmlns="http://www.w3.org/2000/svg"><path d="M1600 1240q0 27-10 70.5t-21 68.5q-21 50-122 106-94 51-186 51-27 0-52.5-3.5t-57.5-12.5-47.5-14.5-55.5-20.5-49-18q-98-35-175-83-128-79-264.5-215.5t-215.5-264.5q-48-77-83-175-3-9-18-49t-20.5-55.5-14.5-47.5-12.5-57.5-3.5-52.5q0-92 51-186 56-101 106-122 25-11 68.5-21t70.5-10q14 0 21 3 18 6 53 76 11 19 30 54t35 63.5 31 53.5q3 4 17.5 25t21.5 35.5 7 28.5q0 20-28.5 50t-62 55-62 53-28.5 46q0 9 5 22.5t8.5 20.5 14 24 11.5 19q76 137 174 235t235 174q2 1 19 11.5t24 14 20.5 8.5 22.5 5q18 0 46-28.5t53-62 55-62 50-28.5q14 0 28.5 7t35.5 21.5 25 17.5q25 15 53.5 31t63.5 35 54 30q70 35 76 53 3 7 3 21z"></path></svg>',

				'email'   => '<svg class="svg-icon" width="24" height="24" aria-hidden="true" role="img" focusable="false" viewBox="0 0 1792 1792" xmlns="http://www.w3.org/2000/svg"><path d="M1792 710v794q0 66-47 113t-113 47h-1472q-66 0-113-47t-47-113v-794q44 49 101 87 362 246 497 345 57 42 92.5 65.5t94.5 48 110 24.5h2q51 0 110-24.5t94.5-48 92.5-65.5q170-123 498-345 57-39 100-87zm0-294q0 79-49 151t-122 123q-376 261-468 325-10 7-42.5 30.5t-54 38-52 32.5-57.5 27-50 9h-2q-23 0-50-9t-57.5-27-52-32.5-54-38-42.5-30.5q-91-64-262-182.5t-205-142.5q-62-42-117-115.5t-55-136.5q0-78 41.5-130t118.5-52h1472q65 0 112.5 47t47.5 113z"></path></svg>',

				'address' => '<svg class="svg-icon" width="24" height="24" aria-hidden="true" role="img" focusable="false" viewBox="0 0 1792 1792" xmlns="http://www.w3.org/2000/svg"><path d="M1152 640q0-106-75-181t-181-75-181 75-75 181 75 181 181 75 181-75 75-181zm256 0q0 109-33 179l-364 774q-16 33-47.5 52t-67.5 19-67.5-19-46.5-52l-365-774q-33-70-33-179 0-212 150-362t362-150 362 150 150 362z"></path></svg>',
			)
		);

		if ( array_key_exists( $icon, $icons ) ) {
			echo wp_kses(
				$icons[ $icon ],
				array(
					'svg'     => array(
						'class'       => true,
						'xmlns'       => true,
						'width'       => true,
						'height'      => true,
						'viewbox'     => true,
						'aria-hidden' => true,
						'role'        => true,
						'focusable'   => true,
					),
					'path'    => array(
						'fill'      => true,
						'fill-rule' => true,
						'd'         => true,
						'transform' => true,
					),
					'polygon' => array(
						'fill'      => true,
						'fill-rule' => true,
						'points'    => true,
						'transform' => true,
						'focusable' => true,
					),
				)
			);
		}
	}

	/**
	 * Render top info for selective refresh.
	 *
	 * @return void
	 */
	public function render_top_info() {
		get_template_part( 'template-parts/header/top-info' );
	}

	/**
	 * Get setting: Top Info Enable.
	 *
	 * @return array()
	 */
	public static function get_top_info_enable() {
		return array(
			'contact' => static::get_top_info_contact_enable(),
			'buttons' => static::get_top_info_buttons_enable(),
		);
	}

	/**
	 * Get top info class.
	 *
	 * @return string
	 */
	public static function top_info_class() {
		$top_info_align = self::get_top_info_align();

		$top_info_class = ( 'top-info-detail top-info-' . $top_info_align['md'] . '-md top-info-' . $top_info_align['lg'] . '-lg top-info-' . $top_info_align['xlg'] . '-xlg' );

		return apply_filters( 'pressbook_top_info_class', $top_info_class );
	}

	/**
	 * Output the top contact info HTML
	 */
	public static function top_info_contact_html() {
		$contact = self::get_top_info_contact();
		?>
		<ul class="top-info-contact">
		<?php
		foreach ( $contact['order'] as $key => $val ) {
			$contact['field'][ $key ];
			if ( '' !== $contact['field'][ $key ] ) {
				?>
			<li class="top-info-<?php echo esc_attr( $key ); ?>"><?php static::output_icon( $key ); ?><span><?php echo esc_html( $contact['field'][ $key ] ); ?></span></li>
				<?php
			}
		}
		?>
		</ul>
		<?php
	}

	/**
	 * Output the top info buttons HTML
	 */
	public static function top_info_buttons_html() {
		$buttons = self::get_top_info_buttons();
		?>
		<div class="top-info-buttons">
		<?php
		foreach ( $buttons as $key => $val ) {
			if ( '' !== $val['text'] ) {
				?>
			<a <?php echo ( ( (bool) $val['new_tab'] ) ? 'target="blank" ' : '' ); ?>href="<?php echo esc_url( $val['link'] ); ?>" class="top-info-button top-info-button-<?php echo esc_attr( $key ); ?>"><?php echo esc_html( $val['text'] ); ?></a>
				<?php
			}
		}
		?>
		</div>
		<?php
	}
}
